//=========================================
// Conference chair
//-----------------------------------------
// Made for Persistence of vision 3.6
//==========================================  
// Copyright 2007 Gilles Tran http://www.oyonale.com
// -----------------------------------------
// This work is licensed under the Creative Commons Attribution License. 
// To view a copy of this license, visit http://creativecommons.org/licenses/by/3.0/ 
// or send a letter to Creative Commons, 559 Nathan Abbott Way, Stanford, California 94305, USA.
// You are free:
// - to copy, distribute, display, and perform the work
// - to make derivative works
// - to make commercial use of the work
// Under the following conditions:
// - Attribution. You must give the original author credit.
// - For any reuse or distribution, you must make clear to others the license terms of this work.
// - Any of these conditions can be waived if you get permission from the copyright holder.
// Your fair use and other rights are in no way affected by the above. 
//==========================================  
#include "colors.inc"
#declare FPoint=<450,30,-220>;
camera {
    location  <350, 60, -230>*2
    look_at   <0, -50, 100>
    direction z*3
    right     x*image_width/image_height
    aperture 10
    blur_samples 200
    focal_point  FPoint
    confidence 0.99
    variance 1/999

}

//==========================================  
// Textures
//==========================================  

#declare T_Wall= texture{
    pigment {color rgb <1,1,1>} 
    finish{specular 1 roughness 0.05 diffuse 1 ambient 0}
}
#declare T_Plastic= texture{
    pigment {color rgb <1,1,1>*0.01 } 
    finish{specular 1 roughness 0.01 diffuse 1 ambient 0
        reflection {0,0.4}
    }
}
#declare T_Cushion= texture{
    pigment {color rgb <58,98,124>/255} 
    finish{specular 1 roughness 0.02 diffuse 1 ambient 0}
}
#declare T_Floor= texture{
    pigment {image_map{jpeg "tiles.jpg"}}
    normal{bump_map{jpeg "tiles_bump.jpg"} bump_size 0.3} 
    finish{specular 1 roughness 0.02 diffuse 1 ambient 0
    reflection {0,0.4}

}
    rotate x*90
    scale 100
}

//==========================================  
// Chair
//==========================================  
#include "dchaise_pov.inc"
//#declare Chaise=box{<-15,0,-15>,<15,40,15> texture{T_Cushion}}
#declare Chaise=object{Chaise rotate y*180 rotate -y*0}

//==========================================  
// Lamps
//==========================================  
#declare Spot=light_source {
        y*250
        color rgb 150*<0.9,1,1>
        area_light 50*x,50*z,5,5 jitter adaptive 1
        spotlight
        point_at <0, 0, 0>
        radius 10
        tightness 1
        falloff 70
        fade_distance 20
        fade_power 2
}
#declare Spot2=light_source {
        y*250
        color rgb 150*<0.9,1,1>
        spotlight
        point_at <0, 0, 0>
        radius 10
        tightness 1
        falloff 70
        fade_distance 20
        fade_power 2
}

//==========================================  
// Object
//==========================================  
// lights
object{Spot translate FPoint}
object{Spot2 translate FPoint translate <-600,0,300>}

// room
box{<-810,-10,-510>,<810,310,510>  texture{T_Wall}}

// floor
plane{y,0 texture{T_Floor}}

// chairs
#declare intX=100;  // interval between chairs (x)
#declare intZ=100;  // interval between chairs (z)
#declare nX=10;     // number of chairs by row
#declare nZ=6;      // number of chairs by column
#declare s=seed(909);
union{
    #declare i=0;
    #while (i<nZ)
        #declare j=0;
        #while (j<nX)
            object{Chaise rotate y*(-10+rand(s)*20) translate <j*intX,0,i*intZ>+<-5+rand(s)*10,0,5+rand(s)*10>}
            #declare j=j+1;
        #end
        #declare i=i+1;
    #end
    translate -<intX*(nX-1),0,intZ*(nZ-1)>/2-z*intZ
}



